amachine.cli.repair_wheel API documentation

GitLab Repo

# amachine.cli.repair_wheel

View Source

     1import subprocess
     2import sys
     3import glob
     4import os
     5import shutil
     6
     7def repair_wheel():
     8
     9    wheels = glob.glob("./dist/*.whl")
    10
    11    if not wheels:
    12        print("No wheels found in ./dist/")
    13        return
    14
    15    subprocess.run( ["auditwheel", "repair" ] + wheels )
    16
    17    for w in wheels:
    18        os.remove(w)
    19
    20    repaired_wheels = glob.glob("./wheelhouse/*.whl")
    21    for rw in repaired_wheels:
    22        shutil.move(rw, "./dist/")

def repair_wheel(): View Source

     8def repair_wheel():
     9
    10    wheels = glob.glob("./dist/*.whl")
    11
    12    if not wheels:
    13        print("No wheels found in ./dist/")
    14        return
    15
    16    subprocess.run( ["auditwheel", "repair" ] + wheels )
    17
    18    for w in wheels:
    19        os.remove(w)
    20
    21    repaired_wheels = glob.glob("./wheelhouse/*.whl")
    22    for rw in repaired_wheels:
    23        shutil.move(rw, "./dist/")